#!/bin/bash

set -e -u

# (MAIN)

orig_dir=$(pwd)

[ $# != 2 ] && {
	echo "usage: $0 packagename version" >&2
	exit 1
}

[ -d "$orig_dir/debian" ] || {
	echo "error: 'debian' dir not found" >&2
	echo "  you should run this command from the main package dir" >&2
	exit 1
}

pkgname="$1"
release="$2"

# strip N: component from release, if any
release=$(echo "$release" | sed -e 's/[0-9]*://')

#arch=$(uname -m)

echo "
  PACKAGE: $pkgname v.$release
"

DEST="$orig_dir/debian/$pkgname"

tarfile="$pkgname-$release.tar.bz2"


[ -f "$tarfile" ] || {
	echo -e "\nerror: you need to download $tarfile from https://www.thunderbird.net website\n" >&2
	exit 1
}

outdir=$(tar tvfj $tarfile | head -1 | sed -e 's/.* //' -e 's#/.*##')
[ "X$outdir" != "X$pkgname" ] && {
	echo -e "\nerror: can't find '$pkgname' directory in $tarfile\n" >&2
	exit 1
}

echo -en " extracting $tarfile ... "
mkdir -p $DEST/usr/lib
cd $DEST/usr/lib
tar xfpj "$orig_dir/$tarfile"

[ -d "$pkgname" ] || {
	echo "ERROR"
	echo -e "\nerror: directory '$pkgname' not found after extraction .. wrong tarfile?\n" >&2
	exit 1
}
echo "ok"

exit 0
